| Title: | Extract, Convert, and Merge 'pdf' Files from 'zip' Files |
|---|---|
| Description: | Extracts 'zip' files, converts 'Word', 'Excel', and 'html'/'htm' files to 'pdf' format. 'Word' and 'Excel' conversion uses 'VBScript', while 'html'/'htm' conversion uses 'webshot' and 'PhantomJS'. Additionally, the package merges 'pdf' files into a single document. This package is only supported on 'Windows' due to 'VBScript' dependencies. |
| Authors: | Lijin Arakkandathil Thekkathil [aut, cre] |
| Maintainer: | Lijin Arakkandathil Thekkathil <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.5 |
| Built: | 2026-05-11 09:33:00 UTC |
| Source: | https://github.com/lijin-5673/ljexm |
Convert Word & Excel Files to PDFs using 'VBScript'
convert_files_to_pdf(folder_path)convert_files_to_pdf(folder_path)
folder_path |
The directory containing Word and Excel files |
No return value, called for side effects.
Convert HTML/HTM Files to PDF Automatically installs 'PhantomJS' if missing.
convert_html_to_pdf(folder_path)convert_html_to_pdf(folder_path)
folder_path |
The directory where ZIP files are extracted. |
No return value, called for side effects.
Extract ZIP Files in a Given Folder
extract_zip_files(folder_path)extract_zip_files(folder_path)
folder_path |
The directory containing ZIP files |
No return value, called for side effects.
Merge PDFs in Alphabetical Order
merge_pdfs(folder_path)merge_pdfs(folder_path)
folder_path |
The directory containing sub-folders with PDF files |
Character vector with the path of the merged PDF file.
Run the Full Process: Extract, Convert, and Merge PDFs
run_app(folder_path = NULL)run_app(folder_path = NULL)
folder_path |
The directory containing files for processing. If NULL, the user is prompted to select a directory interactively. |
No return value, called for side effects.